@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary::Array;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010';
+our $VERSION   = '0.011';
 
 use Sub::HandlesVia::HandlerLibrary;
 our @ISA = 'Sub::HandlesVia::HandlerLibrary';
@@ -14,7 +14,7 @@ use Sub::HandlesVia::Handler qw( handler );
 use Types::Standard qw( ArrayRef Optional Str CodeRef Int Item Any Ref Defined FileHandle );
 
 our @METHODS = qw( count is_empty all elements flatten get pop push shift
-	unshift clear first first_index reduce set accessor natatime
+	unshift clear first first_index reduce set accessor natatime any
 	shallow_clone map grep sort reverse sort_in_place splice shuffle
 	shuffle_in_place uniq uniq_in_place delete insert flatten flatten_deep
 	join print head tail apply pick_random for_each for_each_pair );
@@ -214,6 +214,16 @@ sub first {
 		template  => '&List::Util::first($ARG, @{$GET})',
 }
 
+sub any {
+	require List::Util;
+	handler
+		name      => 'Array:any',
+		args      => 1,
+		signature => [CodeRef],
+		usage     => '$coderef',
+		template  => '&List::Util::any($ARG, @{$GET})',
+}
+
 sub first_index {
 	my $me = __PACKAGE__;
 	handler
